@@ -118,18 +118,19 @@ set interfaces {{ type }} {{ name }} peer {{ peer.name }} public-key '{{ peer.pu
 
 
 vyos_ospf = """
-{% if ospf["ospf_redistribute"] is defined %}
+{% if ospf["ospf_redistribute"] -%}
+
 
 {% for redis in ospf["ospf_redistribute"] %}
 
-{% if redis.state == "present" %}
+{% if redis.state == "present" -%}
 set protocols ospf redistribute {{ redis.redistribute }}
 
-{% if redis.route_map is defined and redis.route_map|length > 1 %}
+{% if redis.route_map is defined and redis.route_map|length > 1 -%}
 set protocols ospf redistribute {{ redis.redistribute }} route-map {{ redis.route_map }}
 {% endif %}
 
-{% elif redis.state == "absent"%}
+{% elif redis.state == "absent" -%}
 delete protocol ospf redistribute {{ redis.redistribute }}
 {% endif %}
 
@@ -147,7 +148,7 @@ delete protocols ospf area 0 parameters router-id
 
 {% for net in ospf["ospf_networks"] -%}
 
-{% if net.state == "absent" -%}
+{% if net.state == "absent" or net.state == "deleted" -%}
 delete protocols ospf area {{ net.area }} network {{ net.subnet }}{{ net.mask }}
 
 {% else -%}
@@ -194,6 +195,12 @@ set protocols bgp neighbor {{ peer_ip }} interface source-interface {{ source_in
 set protocols bgp neighbor {{ peer_ip }} interface remote-as {{ remote_as }}
 {% endif -%}
 
+
+{%if nexthop_self is defined and nexthop_self -%}
+set protocols bgp neighbor {{ peer_ip }} address-family ipv4-unicast nexhop-self
+{% endif -%}
+
+
 {%if extended_next_hop -%}
 set protocols bgp neighbor {{ peer_ip }} capability extended-nexthop
 {% endif -%}
@@ -230,42 +237,96 @@ set protocols bgp neighbor {{ peer_ip }} address-family ipv6-unicast route-map {
 """
 
 vyos_routemap = """
-{%- for map in route_maps -%}
-
-{%if map.desc is defined and map.desc|length -%}
-set policy route-map {{ map.name }} description '{{map.desc}}'
+{% if desc is defined and desc|length -%}
+set policy route-map {{ name }} description '{{ desc }}'
 {%endif-%}
 
-{%- for rule in map.rules -%}
+{%- for rule in rules -%}
 
-{%if rule.state == "absent" -%}
+{% if rule.state == "absent" or rule.state == "deleted" -%}
 delete policy route-map {{ map.name }} rule {{ rule.rule_no }}
 
 {% else -%}
-set policy route-map {{ map.name }} rule {{ rule.rule_no }} action {{ rule.action }}
-set policy route-map {{ map.name }} rule {{ rule.rule_no }} match {{ rule.match }}
-{%endif-%}
-{% endfor -%}{% endfor -%}"""
+set policy route-map {{ name }} rule {{ rule.rule_no }} action {{ rule.action }}
+set policy route-map {{ name }} rule {{ rule.rule_no }} match {{ rule.match }}
+{% endif -%}
+{% endfor -%}
+"""
 
 
 vyos_prefix_list = """
-{%- for list in prefix_lists -%}
+set policy prefix-list {{ name }}
 
-{%if list.desc is defined and list.desc|length -%}
-set policy prefix-list {{ list.name }} description '{{ list.desc }}'
-{%endif-%}
+{% if desc is defined and desc|length -%}
+set policy prefix-list {{ name }} description '{{ desc }}'
+{% endif -%}
 
-{%- for rule in list.rules -%}
+{%- for rule in rules -%}
 
-{%if rule.state == "absent" -%}
-delete policy prefix-list {{ list.name }} rule {{ rule.rule_no }}
+{% if rule.state == "absent" or state == "deleted" -%}
+delete policy prefix-list {{ name }} rule {{ rule.rule_no }}
 
 {% else -%}
-set policy prefix-list {{ list.name }} rule {{ rule.rule_no }} action {{ rule.action }}
-set policy prefix-list {{ list.name }} rule {{ rule.rule_no }} {{ rule.match[0]["length"] }}
-set policy prefix-list {{ list.name }} rule {{ rule.rule_no }} prefix {{ rule.match[0]["prefix"] }}
+
+
+set policy prefix-list {{ name }} rule {{ rule.rule_no }} action {{ rule.action }}
+
+
+{% if rule.desc is defined and rule.desc|length -%}
+set policy prefix-list {{ name }} rule {{ rule.rule_no }} description '{{ rule.desc }}'
+{% endif -%}
+
+{% if rule["match"]["le"] is defined and rule["match"]["le"] is not none -%}
+set policy prefix-list {{ name }} rule {{ rule.rule_no }} le {{ rule["match"]["le"] }}
+{% endif -%}
+
+{% if rule["match"]["ge"] is defined and rule["match"]["ge"] is not none -%}
+set policy prefix-list {{ name }} rule {{ rule.rule_no }} ge {{ rule["match"]["ge"] }}
+{% endif -%}
+
+set policy prefix-list {{ name }} rule {{ rule.rule_no }} prefix {{ rule["match"]["prefix"] }}
+
 {%endif-%}
-{% endfor -%}{% endfor -%}"""
+
+{% endfor -%}
+"""
+
+vyos_prefix_list6 = """
+set policy prefix-list6 {{ name }}
+
+{% if desc is defined and desc|length -%}
+set policy prefix-list6 {{ name }} description '{{ desc }}'
+{% endif -%}
+
+{%- for rule in rules -%}
+
+{% if rule.state == "absent" or state == "deleted" -%}
+delete policy prefix-list6 {{ name }} rule {{ rule.rule_no }}
+
+{% else -%}
+
+
+set policy prefix-list6 {{ name }} rule {{ rule.rule_no }} action {{ rule.action }}
+
+
+{% if rule.desc is defined and rule.desc|length -%}
+set policy prefix-list6 {{ name }} rule {{ rule.rule_no }} description '{{ rule.desc }}'
+{% endif -%}
+
+{% if rule["match"]["le"] is defined and rule["match"]["le"] is not none -%}
+set policy prefix-list6 {{ name }} rule {{ rule.rule_no }} le {{ rule["match"]["le"] }}
+{% endif -%}
+
+{% if rule["match"]["ge"] is defined and rule["match"]["ge"] is not none -%}
+set policy prefix-list6 {{ name }} rule {{ rule.rule_no }} ge {{ rule["match"]["ge"] }}
+{% endif -%}
+
+set policy prefix-list6 {{ name }} rule {{ rule.rule_no }} prefix {{ rule["match"]["prefix"] }}
+
+{%endif-%}
+
+{% endfor -%}
+"""
 
 
 vyos_static = """
